@@ -7,7 +7,7 @@ require Exporter;
 );
 use warnings;
 use strict;
-our $VERSION = '0.29_02';
+our $VERSION = '0.30_01';
 
 # Are we running as XS?
 
@@ -130,5 +130,10 @@ sub write_json
     close $out or die $!;
 }
 
+sub run
+{
+    goto &create;
+}
+
 1;
 
